@@ -81,7 +81,7 @@ BmpInput::open(const std::string& name, ImageSpec& spec)
     m_spec.attribute("YResolution", (int)m_dib_header.vres);
     m_spec.attribute("ResolutionUnit", "m");
 
-    // comupting size of one scanline - this is the size of one scanline that
+    // computing size of one scanline - this is the size of one scanline that
     // is stored in the file, not in the memory
     int swidth = 0;
     switch (m_dib_header.bpp) {
@@ -123,7 +123,7 @@ BmpInput::open(const std::string& name, ImageSpec& spec)
 
 
 bool
-BmpInput::read_native_scanline(int subimage, int miplevel, int y, int z,
+BmpInput::read_native_scanline(int subimage, int miplevel, int y, int /*z*/,
                                void* data)
 {
     lock_guard lock(m_mutex);
@@ -134,7 +134,7 @@ BmpInput::read_native_scanline(int subimage, int miplevel, int y, int z,
         return false;
 
     // if the height is positive scanlines are stored bottom-up
-    if (m_dib_header.width >= 0)
+    if (m_dib_header.height >= 0)
         y = m_spec.height - y - 1;
     const int64_t scanline_off = y * m_padded_scanline_size;
 
