@@ -1085,7 +1085,7 @@ namespace cineon
 		 * \brief Returns the size of the header
 		 * \return 2048 as defined by the standard
 		 */
-		const U32			Size() const;
+		U32                 Size() const;
 
 		/*!
 		 * \brief Calculate all of the offset members in the header
@@ -1128,7 +1128,7 @@ namespace cineon
 		return this->DetermineByteSwap(this->magicNumber);
 	}
 
-	inline const U32 Header::Size() const
+	inline U32 Header::Size() const
 	{
 		return 2048;
 	}
