@@ -1171,13 +1171,13 @@ namespace dpx
 		
 		/*!
 		 * \brief Get the shutter angle of the motion picture camera
-		 * \return degress of the temporal sampling aperture
+		 * \return degrees of the temporal sampling aperture
 		 */
 		inline R32			ShutterAngle() const;
 		
 		/*!
 		 * \brief Set the shutter angle of the motion picture camera
-		 * \param angle degress of the temporal sampling aperture
+		 * \param angle degrees of the temporal sampling aperture
 		 */
 		inline void			SetShutterAngle(const R32 angle);
 		
@@ -1262,25 +1262,25 @@ namespace dpx
 		inline void			SetFieldNumber(const U8 fn);
 		
 		/*!
-		 * \brief Get the video sournce
+		 * \brief Get the video source
 		 * \return signal
 		 */
 		inline VideoSignal	Signal() const;
 		
 		/*!
-		 * \brief Set the video sournce
+		 * \brief Set the video source
 		 * \param vs signal
 		 */
 		inline void			SetSignal(const VideoSignal vs);
 		
 		/*!
-		 * \brief Get the clock rate at which samples were aquired
+		 * \brief Get the clock rate at which samples were acquired
 		 * \return rate
 		 */
 		inline R32			HorizontalSampleRate() const;
 		
 		/*!
-		 * \brief Set the clock rate at which samples were aquired
+		 * \brief Set the clock rate at which samples were acquired
 		 * \param rate rate
 		 */
 		inline void			SetHorizontalSampleRate(const R32 rate);
@@ -1448,7 +1448,7 @@ namespace dpx
 		 * \brief Returns the size of the header
 		 * \return 2048 as defined by the standard
 		 */
-		const U32			Size() const;
+		U32			Size() const;
 
 		/*!
 		 * \brief Calculate all of the offset members in the header
@@ -1509,7 +1509,7 @@ namespace dpx
 		return this->DetermineByteSwap(this->magicNumber);
 	}
 
-	inline const U32 Header::Size() const
+	inline U32 Header::Size() const
 	{
 		return 2048;
 	}
@@ -1714,7 +1714,7 @@ namespace dpx
 	inline R32 GenericHeader::LowQuantity(const int i) const
 	{
 		if (i < 0 || i >= MAX_ELEMENTS)
-			return 0xffffffff;
+			return R32(0xffffffff);
 		return this->chan[i].lowQuantity;
 	}
 
@@ -1742,7 +1742,7 @@ namespace dpx
 	inline R32 GenericHeader::HighQuantity(const int i) const
 	{
 		if (i < 0 || i >= MAX_ELEMENTS)
-			return 0xffffffff;
+			return R32(0xffffffff);
 		return this->chan[i].highQuantity;
 	}
 
