@@ -11,8 +11,6 @@
 #include <OpenImageIO/imageio.h>
 #include <OpenImageIO/thread.h>
 
-#include <OpenEXR/ImathVec.h>
-
 #include "field3d_pvt.h"
 using namespace OIIO_NAMESPACE::f3dpvt;
 
@@ -459,10 +457,11 @@ Field3DInput::close()
 
 
 bool
-Field3DInput::read_native_scanline(int subimage, int miplevel, int y, int z,
-                                   void* data)
+Field3DInput::read_native_scanline(int /*subimage*/, int /*miplevel*/,
+                                   int /*y*/, int /*z*/, void* /*data*/)
 {
     // scanlines not supported
+    error("Field3D does not support scanline I/O");
     return false;
 }
 
