@@ -9,7 +9,6 @@
 
 #include "rgbe.h"
 #include <OpenImageIO/filesystem.h>
-#include <OpenImageIO/fmath.h>
 #include <OpenImageIO/imageio.h>
 #include <OpenImageIO/strutil.h>
 
@@ -128,8 +127,8 @@ HdrOutput::open(const std::string& name, const ImageSpec& newspec,
 
 
 bool
-HdrOutput::write_scanline(int y, int z, TypeDesc format, const void* data,
-                          stride_t xstride)
+HdrOutput::write_scanline(int /*y*/, int /*z*/, TypeDesc format,
+                          const void* data, stride_t xstride)
 {
     data  = to_native_scanline(format, data, xstride, scratch);
     int r = RGBE_WritePixels_RLE(m_fd, (float*)data, m_spec.width, 1,
