@@ -333,7 +333,7 @@ convert_file(const std::string& in_filename, const std::string& out_filename)
     if (!out) {
         std::cerr
             << "iconvert ERROR: Could not find an ImageIO plugin to write \""
-            << out_filename << "\" :" << geterror() << "\n";
+            << out_filename << "\" : " << geterror() << "\n";
         return false;
     }
 
@@ -497,5 +497,10 @@ main(int argc, char* argv[])
         ok = convert_file(filenames[0], filenames[1]);
     }
 
+    // Force all files to close, ugh, it's the only way I can find to solve
+    // an occasional problem with static destructor order fiasco with
+    // field3d when building with EMBEDPLUGINS=0 on MacOS.
+    ImageCache::create()->close_all();
+
     return ok ? EXIT_SUCCESS : EXIT_FAILURE;
 }
