@@ -1,31 +1,6 @@
-/*
-  Copyright 2017 Larry Gritz et al. All Rights Reserved.
-
-  Redistribution and use in source and binary forms, with or without
-  modification, are permitted provided that the following conditions are
-  met:
-  * Redistributions of source code must retain the above copyright
-    notice, this list of conditions and the following disclaimer.
-  * Redistributions in binary form must reproduce the above copyright
-    notice, this list of conditions and the following disclaimer in the
-    documentation and/or other materials provided with the distribution.
-  * Neither the name of the software's owners nor the names of its
-    contributors may be used to endorse or promote products derived from
-    this software without specific prior written permission.
-  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-  (This is the Modified BSD License)
-*/
+// Copyright 2008-present Contributors to the OpenImageIO project.
+// SPDX-License-Identifier: BSD-3-Clause
+// https://github.com/OpenImageIO/oiio/blob/master/LICENSE.md
 
 // clang-format off
 
@@ -51,7 +26,7 @@ OIIO_NAMESPACE_BEGIN
 /// * Google Benchmark https://github.com/google/benchmark/blob/master/include/benchmark/benchmark_api.h
 
 template <class T>
-OIIO_FORCEINLINE T const& DoNotOptimize (T const &val);
+T const& DoNotOptimize (T const &val);
 
 
 /// clobber_all_memory() is a helper function for timing benchmarks that
@@ -66,7 +41,7 @@ OIIO_FORCEINLINE void clobber_all_memory();
 /// A call to clobber(p) fools the compiler into thinking that p (or *p, for
 /// the pointer version) might potentially have its memory altered. The
 /// implementation actually does nothing, but it's in another module, so the
-/// compiler won't know this and will be conservative about any assupmtions
+/// compiler won't know this and will be conservative about any assumptions
 /// of what's in p. This is helpful for benchmarking, to help erase any
 /// preconceptions the optimizer has about what might be in a variable.
 
@@ -76,6 +51,15 @@ OIIO_FORCEINLINE void clobber (const void* p) { clobber ((void*)p); }
 template<typename T>
 OIIO_FORCEINLINE T& clobber (T& p) { clobber(&p); return p; }
 
+// Multi-argument clobber, added in OIIO 2.2.2
+template<typename T, typename ...Ts>
+OIIO_FORCEINLINE void clobber (T& p, Ts&... ps)
+{
+    clobber(&p);
+    if (sizeof...(Ts) > 0)
+        clobber(ps...);
+}
+
 
 
 
@@ -91,7 +75,7 @@ OIIO_FORCEINLINE T& clobber (T& p) { clobber(&p); return p; }
 /// iterations based on their timing. For most use cases, it's fire and
 /// forget.
 ///
-/// Generally, the most and least expesive trials will be discarded (all
+/// Generally, the most and least expensive trials will be discarded (all
 /// sorts of things can happen to give you a few spurious results) and then
 /// the remainder of trials will be used to compute the average, standard
 /// deviation, range, and median value, in ns per iteration as well as
@@ -332,7 +316,7 @@ time_trial(FUNC func, int ntrials = 1, int nrepeats = 1, double* range = NULL)
     while (ntrials-- > 0) {
         Timer timer;
         for (int i = 0; i < nrepeats; ++i) {
-            // Be sure that the repeated calls to func aren't optimzed away:
+            // Be sure that the repeated calls to func aren't optimized away:
             clobber_all_memory();
             func();
         }
