@@ -16,6 +16,8 @@
 
 #pragma once
 
+#define OIIO_FILESYSTEM_H
+
 #include <cstdint>
 #include <cstdio>
 #include <ctime>
@@ -209,11 +211,23 @@ OIIO_API void open (OIIO::ifstream &stream, string_view path,
 OIIO_API void open (OIIO::ofstream &stream, string_view path,
                     std::ios_base::openmode mode = std::ios_base::out);
 
+/// Version of C open() that can handle UTF-8 paths, returning an integer
+/// file descriptor. Note that the flags are passed to underlying calls to
+/// open()/_open() and therefore may be OS specific -- use with caution! If
+/// you want more OS-agnostic file opening, prefer the FILE or stream
+/// methods of IO. (N.B.: use of this function requires the caller to
+/// `#include <fcntl.h>` in order to get the definitions of the flags.)
+OIIO_API int open (string_view path, int flags);
 
 /// Read the entire contents of the named text file and place it in str,
 /// returning true on success, false on failure.
 OIIO_API bool read_text_file (string_view filename, std::string &str);
 
+/// Write the entire contents of the string `str` to the file, overwriting
+/// any prior contents of the file (if it existed), returning true on
+/// success, false on failure.
+OIIO_API bool write_text_file (string_view filename, string_view str);
+
 /// Read a maximum of n bytes from the named file, starting at position pos
 /// (which defaults to the start of the file), storing results in
 /// buffer[0..n-1]. Return the number of bytes read, which will be n for
@@ -249,7 +263,7 @@ OIIO_API void convert_native_arguments (int argc, const char *argv[]);
 ///                           NOT have been selected by 'x'.
 ///     Note that START may be > FINISH, or STEP may be negative.
 ///  * Multiple values or ranges, separated by a comma (e.g., "3,4,10-20x2")
-/// Retrn true upon success, false if the description was too malformed
+/// Return true upon success, false if the description was too malformed
 /// to generate a sequence.
 OIIO_API bool enumerate_sequence (string_view desc,
                                   std::vector<int> &numbers);
@@ -328,12 +342,12 @@ public:
     virtual bool opened () const { return mode() != Closed; }
     virtual int64_t tell () { return m_pos; }
     virtual bool seek (int64_t offset) { m_pos = offset; return true; }
-    virtual size_t read (void *buf, size_t size) { return 0; }
-    virtual size_t write (const void *buf, size_t size) { return 0; }
+    virtual size_t read (void *buf, size_t size);
+    virtual size_t write (const void *buf, size_t size);
     // pread(), pwrite() are stateless, do not alter the current file
     // position, and are thread-safe (against each other).
-    virtual size_t pread (void *buf, size_t size, int64_t offset) { return 0; }
-    virtual size_t pwrite (const void *buf, size_t size, int64_t offset) { return 0; }
+    virtual size_t pread (void *buf, size_t size, int64_t offset);
+    virtual size_t pwrite (const void *buf, size_t size, int64_t offset);
     virtual size_t size () const { return 0; }
     virtual void flush () const { }
 
@@ -351,25 +365,18 @@ public:
     bool seek (int64_t offset, int origin) {
         return seek ((origin == SEEK_SET ? offset : 0) +
                      (origin == SEEK_CUR ? offset+tell() : 0) +
-                     (origin == SEEK_END ? size() : 0));
+                     (origin == SEEK_END ? offset+int64_t(size()) : 0));
     }
 
-#if OIIO_VERSION >= 20101
     #define OIIO_IOPROXY_HAS_ERROR 1
-    std::string error() const { return m_error; }
-    void error(string_view e) { m_error = e; }
-#else
-    std::string error() const { return ""; }
-    void error(string_view e) { }
-#endif
+    std::string error() const;
+    void error(string_view e);
 
 protected:
     std::string m_filename;
     int64_t m_pos = 0;
     Mode m_mode   = Closed;
-#ifdef OIIO_IOPROXY_HAS_ERROR
     std::string m_error;
-#endif
 };
 
 
