@@ -7,16 +7,12 @@
 
 #include <iostream>
 
-#include <OpenEXR/ImathFun.h>
-#include <OpenEXR/half.h>
-
 #include <QComboBox>
 #include <QLabel>
 #include <QMouseEvent>
 #include <QProgressBar>
 
 #include "ivutils.h"
-#include <OpenImageIO/fmath.h>
 #include <OpenImageIO/strutil.h>
 #include <OpenImageIO/timer.h>
 
@@ -37,9 +33,9 @@ gl_err_to_string(GLenum err)
 }
 
 
-#define GLERRPRINT(msg)                                                        \
-    for (GLenum err = glGetError(); err != GL_NO_ERROR; err = glGetError())    \
-        std::cerr << "GL error " << msg << " " << (int)err << " - "            \
+#define GLERRPRINT(msg)                                                     \
+    for (GLenum err = glGetError(); err != GL_NO_ERROR; err = glGetError()) \
+        std::cerr << "GL error " << msg << " " << (int)err << " - "         \
                   << gl_err_to_string(err) << "\n";
 
 
@@ -445,7 +441,7 @@ handle_orientation(int orientation, int width, int height, float& scale_x,
             // substract 1 to get the right index.
             --point_x;
         break;
-    case 3:  // bottom up, rigth to left (rotated 180).
+    case 3:  // bottom up, right to left (rotated 180).
         scale_x = -1;
         scale_y = -1;
         point_x = width - point_x;
@@ -589,7 +585,7 @@ IvGL::paintGL()
             // FIXME: This can get too slow. Some ideas: avoid sending the tex
             // images more than necessary, figure an optimum texture size, use
             // multiple texture objects.
-            load_texture(xstart, ystart, tile_width, tile_height, percent);
+            load_texture(xstart, ystart, tile_width, tile_height);
             gl_rect(xstart, ystart, xstart + tile_width, ystart + tile_height,
                     0, smin, tmin, smax, tmax);
             percent += tile_advance;
@@ -615,7 +611,7 @@ IvGL::paintGL()
 
 
 void
-IvGL::shadowed_text(float x, float y, float z, const std::string& s,
+IvGL::shadowed_text(float x, float y, float /*z*/, const std::string& s,
                     const QFont& font)
 {
     /*
@@ -1076,15 +1072,15 @@ IvGL::clamp_view_to_window()
 
     // Don't let us scroll off the edges
     if (zoomedwidth >= w) {
-        m_centerx = Imath::clamp(m_centerx, xmin + 0.5f * w / m_zoom,
-                                 xmax - 0.5f * w / m_zoom);
+        m_centerx = OIIO::clamp(m_centerx, xmin + 0.5f * w / m_zoom,
+                                xmax - 0.5f * w / m_zoom);
     } else {
         m_centerx = img->oriented_full_x() + img->oriented_full_width() / 2;
     }
 
     if (zoomedheight >= h) {
-        m_centery = Imath::clamp(m_centery, ymin + 0.5f * h / m_zoom,
-                                 ymax - 0.5f * h / m_zoom);
+        m_centery = OIIO::clamp(m_centery, ymin + 0.5f * h / m_zoom,
+                                ymax - 0.5f * h / m_zoom);
     } else {
         m_centery = img->oriented_full_y() + img->oriented_full_height() / 2;
     }
@@ -1181,7 +1177,7 @@ IvGL::mouseMoveEvent(QMouseEvent* event)
         float dx = (pos.x() - m_mousex);
         float dy = (pos.y() - m_mousey);
         float z  = m_viewer.zoom() * (1.0 + 0.005 * (dx + dy));
-        z        = Imath::clamp(z, 0.01f, 256.0f);
+        z        = OIIO::clamp(z, 0.01f, 256.0f);
         m_viewer.zoom(z);
         m_viewer.fitImageToWindowAct->setChecked(false);
     } else if (do_wipe) {
@@ -1249,8 +1245,8 @@ IvGL::get_focus_image_pixel(int& x, int& y)
     float normx = (float)(m_mousex + 0.5f) / w;
     float normy = (float)(m_mousey + 0.5f) / h;
     // imgx,imgy are the position of the mouse, in pixel coordinates
-    float imgx = Imath::lerp(left, right, normx);
-    float imgy = Imath::lerp(top, bottom, normy);
+    float imgx = OIIO::lerp(left, right, normx);
+    float imgy = OIIO::lerp(top, bottom, normy);
     // So finally x,y are the coordinates of the image pixel (on [0,res-1])
     // underneath the mouse cursor.
     //FIXME: Shouldn't this take image rotation into account?
@@ -1441,7 +1437,7 @@ IvGL::typespec_to_opengl(const ImageSpec& spec, int nchannels, GLenum& gltype,
 
 
 void
-IvGL::load_texture(int x, int y, int width, int height, float percent)
+IvGL::load_texture(int x, int y, int width, int height)
 {
     const ImageSpec& spec = m_current_image->spec();
     // Find if this has already been loaded.
@@ -1453,11 +1449,6 @@ IvGL::load_texture(int x, int y, int width, int height, float percent)
         }
     }
 
-    // Disabling progress report. Seems clear after some research that we cannot
-    // update the bar (not even with a signal) within a paint function without
-    // messing up the openGL context
-    //m_viewer.statusProgress->setValue ((int)(percent*100));
-    //m_viewer.statusProgress->update ();
     setCursor(Qt::WaitCursor);
 
     int nchannels = spec.nchannels;
