@@ -61,6 +61,11 @@ public:
     virtual bool read_native_scanline(int subimage, int miplevel, int y, int z,
                                       void* data) override;
     virtual bool close() override;
+    virtual bool set_ioproxy(Filesystem::IOProxy* ioproxy) override
+    {
+        m_io = ioproxy;
+        return true;
+    }
     const std::string& filename() const { return m_filename; }
     void* coeffs() const { return m_coeffs; }
     struct my_error_mgr {
@@ -87,6 +92,7 @@ private:
     std::vector<unsigned char> m_cmyk_buf;  // For CMYK translation
     Filesystem::IOProxy* m_io = nullptr;
     std::unique_ptr<Filesystem::IOProxy> m_local_io;
+    std::unique_ptr<ImageSpec> m_config;  // Saved copy of configuration spec
 
     void init()
     {
@@ -99,6 +105,7 @@ private:
         m_jerr.jpginput = this;
         m_io            = nullptr;
         m_local_io.reset();
+        m_config.reset();
     }
 
     // Rummage through the JPEG "APP1" marker pointed to by buf, decoding
