@@ -5,8 +5,6 @@
 #include <cmath>
 #include <memory>
 
-#include <OpenEXR/half.h>
-
 #include <OpenImageIO/dassert.h>
 #include <OpenImageIO/filter.h>
 #include <OpenImageIO/imagebuf.h>
@@ -50,7 +48,7 @@
 // * Use the iterator Black or Clamp wrap modes to avoid lots of special
 //   cases inside the pixel loops.
 // * Use OIIO_DISPATCH_* macros to call type-specialized templated
-//   implemenations.  It is permissible to use OIIO_DISPATCH_COMMON_TYPES_*
+//   implementations.  It is permissible to use OIIO_DISPATCH_COMMON_TYPES_*
 //   to tame the cross-product of types, especially for binary functions
 //   (A,B inputs as well as R output).
 ///////////////////////////////////////////////////////////////////////////
@@ -113,7 +111,7 @@ ImageBufAlgo::IBAprep(ROI& roi, ImageBuf* dst, const ImageBuf* A,
         // If the dst is initialized but is a cached image, we'll need
         // to fully read it into allocated memory so that we're able
         // to write to it subsequently.
-        dst->make_writeable(true);
+        dst->make_writable(true);
 
         // Merge source metadata into destination if requested.
         if (prepflags & IBAprep_MERGE_METADATA) {
@@ -341,40 +339,11 @@ ImageBufAlgo::IBAprep(ROI& roi, ImageBuf* dst, const ImageBuf* A,
 
 
 
-/// Given data types a and b, return a type that is a best guess for one
-/// that can handle both without any loss of range or precision.
+// DEPRECATED(2.3): Replaced by TypeDesc::type_merge(BASETYPE,BASETYPE)
 TypeDesc::BASETYPE
 ImageBufAlgo::type_merge(TypeDesc::BASETYPE a, TypeDesc::BASETYPE b)
 {
-    // Same type already? done.
-    if (a == b)
-        return a;
-    if (a == TypeDesc::UNKNOWN)
-        return b;
-    if (b == TypeDesc::UNKNOWN)
-        return a;
-    // Canonicalize so a's size (in bytes) is >= b's size in bytes. This
-    // unclutters remaining cases.
-    if (TypeDesc(a).size() < TypeDesc(b).size())
-        std::swap(a, b);
-    // Double or float trump anything else
-    if (a == TypeDesc::DOUBLE || a == TypeDesc::FLOAT)
-        return a;
-    if (a == TypeDesc::UINT32
-        && (b == TypeDesc::UINT16 || b == TypeDesc::UINT8))
-        return a;
-    if (a == TypeDesc::INT32
-        && (b == TypeDesc::INT16 || b == TypeDesc::UINT16 || b == TypeDesc::INT8
-            || b == TypeDesc::UINT8))
-        return a;
-    if ((a == TypeDesc::UINT16 || a == TypeDesc::HALF) && b == TypeDesc::UINT8)
-        return a;
-    if ((a == TypeDesc::INT16 || a == TypeDesc::HALF)
-        && (b == TypeDesc::INT8 || b == TypeDesc::UINT8))
-        return a;
-    // Out of common cases. For all remaining edge cases, punt and say that
-    // we prefer float.
-    return TypeDesc::FLOAT;
+    return TypeDesc::basetype_merge(a, b);
 }
 
 
@@ -1198,7 +1167,7 @@ ImageBufAlgo::fillholes_pushpull(ImageBuf& dst, const ImageBuf& src, ROI roi,
     // auto-deleted when the function exits.
     std::vector<std::shared_ptr<ImageBuf>> pyramid;
 
-    // First, make a writeable copy of the original image (converting
+    // First, make a writable copy of the original image (converting
     // to float as a convenience) as the top level of the pyramid.
     ImageSpec topspec = src.spec();
     topspec.set_format(TypeDesc::FLOAT);
