@@ -5,6 +5,7 @@
 #include <fstream>
 #include <sstream>
 
+#include <OpenImageIO/Imath.h>
 #include <OpenImageIO/filesystem.h>
 #include <OpenImageIO/imageio.h>
 #include <OpenImageIO/platform.h>
@@ -31,6 +32,8 @@ test_filename_decomposition()
     std::cout << "Testing filename, extension, parent_path\n";
     OIIO_CHECK_EQUAL(Filesystem::filename(test), "filename.ext");
     OIIO_CHECK_EQUAL(Filesystem::extension(test), ".ext");
+    OIIO_CHECK_EQUAL(Filesystem::extension("./foo.dir/../blah/./bar/file.ext"),
+                     ".ext");
     OIIO_CHECK_EQUAL(Filesystem::extension("/directory/filename"), "");
     OIIO_CHECK_EQUAL(Filesystem::extension("/directory/filename."), ".");
     OIIO_CHECK_EQUAL(Filesystem::parent_path(test), "/directoryA/directory");
@@ -515,7 +518,7 @@ test_mem_proxies()
 
 
 int
-main(int argc, char* argv[])
+main(int /*argc*/, char* /*argv*/[])
 {
     test_filename_decomposition();
     test_filename_searchpath_find();
