@@ -2,6 +2,10 @@
 // SPDX-License-Identifier: BSD-3-Clause
 // https://github.com/OpenImageIO/oiio/blob/master/LICENSE.md
 
+#if (defined __MINGW32__) || (defined __MINGW64__) && !(defined _POSIX_C_SOURCE)
+#    define _POSIX_C_SOURCE 1  // for localtime_r
+#endif
+
 #include <cstdio>
 #include <cstdlib>
 #include <cstring>
@@ -41,10 +45,10 @@
 #ifdef _WIN32
 #    define WIN32_LEAN_AND_MEAN
 #    define DEFINE_CONSOLEV2_PROPERTIES
-#    include <Psapi.h>
 #    include <cstdio>
 #    include <io.h>
 #    include <malloc.h>
+#    include <psapi.h>
 #else
 #    include <sys/resource.h>
 #endif
@@ -207,7 +211,7 @@ Sysutil::physical_memory()
 void
 Sysutil::get_local_time(const time_t* time, struct tm* converted_time)
 {
-#ifdef _MSC_VER
+#ifdef _WIN32
     localtime_s(converted_time, time);
 #else
     localtime_r(time, converted_time);
@@ -291,7 +295,7 @@ Sysutil::terminal_columns()
 {
     int columns = 80;  // a decent guess, if we have nothing more to go on
 
-#if defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD__)           \
+#if defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD__) \
     || defined(__FreeBSD_kernel__) || defined(__GNU__)
     struct winsize w;
     ioctl(0, TIOCGWINSZ, &w);
@@ -315,7 +319,7 @@ Sysutil::terminal_rows()
 {
     int rows = 24;  // a decent guess, if we have nothing more to go on
 
-#if defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD__)           \
+#if defined(__linux__) || defined(__APPLE__) || defined(__FreeBSD__) \
     || defined(__FreeBSD_kernel__) || defined(__GNU__)
     struct winsize w;
     ioctl(0, TIOCGWINSZ, &w);
@@ -482,10 +486,10 @@ Term::ansi_bgcolor(int r, int g, int b)
 
 
 bool
-#if !defined(_MSC_VER)
-Sysutil::put_in_background(int argc, char* argv[])
-#else
+#ifdef _WIN32
 Sysutil::put_in_background(int, char*[])
+#else
+Sysutil::put_in_background(int argc, char* argv[])
 #endif
 {
     // You would think that this would be sufficient:
