@@ -29,7 +29,6 @@
 #include <OpenImageIO/thread.h>
 
 #include <boost/container/flat_map.hpp>
-#include <boost/thread/tss.hpp>
 
 #if 0
 
@@ -45,7 +44,7 @@ namespace {
 
 template<typename T> class Queue {
 public:
-    Queue(int size) {}
+    Queue(int /*size*/) {}
     bool push(T const& value)
     {
         std::unique_lock<Mutex> lock(this->mutex);
@@ -210,7 +209,8 @@ public:
             = std::any_of(this->threads.begin(), this->threads.end(),
                           [](std::unique_ptr<std::thread>& t) {
                               DWORD rcode;
-                              GetExitCodeThread(t->native_handle(), &rcode);
+                              GetExitCodeThread((HANDLE)t->native_handle(),
+                                                &rcode);
                               return rcode != STILL_ACTIVE;
                           });
 
