@@ -7,8 +7,7 @@
 #include <cstdlib>
 #include <string>
 
-#include <OpenEXR/half.h>
-
+#include <OpenImageIO/Imath.h>
 #include <OpenImageIO/dassert.h>
 #include <OpenImageIO/strutil.h>
 #include <OpenImageIO/typedesc.h>
@@ -309,7 +308,7 @@ tostring_formatting::tostring_formatting(
     const char* int_fmt, const char* float_fmt, const char* string_fmt,
     const char* ptr_fmt, const char* aggregate_begin, const char* aggregate_end,
     const char* aggregate_sep, const char* array_begin, const char* array_end,
-    const char* array_sep, int flags)
+    const char* array_sep, int flags, const char* uint_fmt)
     : int_fmt(int_fmt)
     , float_fmt(float_fmt)
     , string_fmt(string_fmt)
@@ -321,15 +320,31 @@ tostring_formatting::tostring_formatting(
     , array_end(array_end)
     , array_sep(array_sep)
     , flags(flags)
+    , uint_fmt(uint_fmt)
 {
 }
 
 
 
+tostring_formatting::tostring_formatting(
+    Notation notation, const char* int_fmt, const char* uint_fmt,
+    const char* float_fmt, const char* string_fmt, const char* ptr_fmt,
+    const char* aggregate_begin, const char* aggregate_end,
+    const char* aggregate_sep, const char* array_begin, const char* array_end,
+    const char* array_sep, int flags)
+    : tostring_formatting(int_fmt, float_fmt, string_fmt, ptr_fmt,
+                          aggregate_begin, aggregate_end, aggregate_sep,
+                          array_begin, array_end, array_sep, flags, uint_fmt)
+{
+    use_sprintf = false;
+}
+
+
+
 template<class T>
-inline std::string
-sprintt(TypeDesc type, const char* format, const tostring_formatting& fmt,
-        const T* v)
+static std::string
+sprint_type(TypeDesc type, const char* format, const tostring_formatting& fmt,
+            const T* v)
 {
     std::string val;
     if (type.arraylen)
@@ -355,9 +370,9 @@ sprintt(TypeDesc type, const char* format, const tostring_formatting& fmt,
 
 
 
-inline std::string
-sprintt(TypeDesc type, const char* format, const tostring_formatting& fmt,
-        const char** v)
+static std::string
+sprint_type(TypeDesc type, const char* format, const tostring_formatting& fmt,
+            const char** v)
 {
     std::string val;
     if (type.arraylen)
@@ -387,6 +402,68 @@ sprintt(TypeDesc type, const char* format, const tostring_formatting& fmt,
 
 
 
+template<class T>
+static std::string
+format_type(TypeDesc type, const char* format, const tostring_formatting& fmt,
+            const T* v)
+{
+    std::string val;
+    if (type.arraylen)
+        val += fmt.array_begin;
+    const size_t n = type.arraylen ? type.arraylen : 1;
+    for (size_t i = 0; i < n; ++i) {
+        if (type.aggregate > 1)
+            val += fmt.aggregate_begin;
+        for (int j = 0; j < (int)type.aggregate; ++j, ++v) {
+            val += Strutil::fmt::format(format, *v);
+            if (type.aggregate > 1 && j < type.aggregate - 1)
+                val += fmt.aggregate_sep;
+        }
+        if (type.aggregate > 1)
+            val += fmt.aggregate_end;
+        if (i < n - 1)
+            val += fmt.array_sep;
+    }
+    if (type.arraylen)
+        val += fmt.array_end;
+    return val;
+}
+
+
+
+static std::string
+format_type(TypeDesc type, const char* format, const tostring_formatting& fmt,
+            const char** v)
+{
+    std::string val;
+    if (type.arraylen)
+        val += fmt.array_begin;
+    const size_t n = type.arraylen ? type.arraylen : 1;
+    for (size_t i = 0; i < n; ++i) {
+        if (type.aggregate > 1)
+            val += fmt.aggregate_begin;
+        for (int j = 0; j < (int)type.aggregate; ++j, ++v) {
+            if (fmt.flags & tostring_formatting::escape_strings)
+                val += Strutil::fmt::format(format,
+                                            *v ? Strutil::escape_chars(*v)
+                                               : std::string());
+            else
+                val += Strutil::fmt::format(format, *v ? *v : "");
+            if (type.aggregate > 1 && j < type.aggregate - 1)
+                val += fmt.aggregate_sep;
+        }
+        if (type.aggregate > 1)
+            val += fmt.aggregate_end;
+        if (i < n - 1)
+            val += fmt.array_sep;
+    }
+    if (type.arraylen)
+        val += fmt.array_end;
+    return val;
+}
+
+
+
 // From OpenEXR
 inline unsigned int
 bitField(unsigned int value, int minBit, int maxBit)
@@ -412,14 +489,32 @@ tostring(TypeDesc type, const void* data, const tostring_formatting& fmt)
     // Perhaps there is a way to use CType<> with a dynamic argument?
     switch (type.basetype) {
     case TypeDesc::UNKNOWN:
-        return sprintt(type, fmt.ptr_fmt, fmt, (void**)data);
-    case TypeDesc::NONE: return sprintt(type, "None", fmt, (void**)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.ptr_fmt, fmt, (void**)data)
+                   : format_type(type, fmt.ptr_fmt, fmt, (void**)data);
+    case TypeDesc::NONE:
+        return fmt.use_sprintf ? sprint_type(type, "None", fmt, (void**)data)
+                               : format_type(type, "None", fmt, (void**)data);
     case TypeDesc::UCHAR:
-        return sprintt(type, fmt.int_fmt, fmt, (unsigned char*)data);
-    case TypeDesc::CHAR: return sprintt(type, fmt.int_fmt, fmt, (char*)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (unsigned char*)data)
+                   : format_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (unsigned char*)data);
+    case TypeDesc::CHAR:
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.int_fmt, fmt, (char*)data)
+                   : format_type(type, fmt.int_fmt, fmt, (char*)data);
     case TypeDesc::USHORT:
-        return sprintt(type, fmt.int_fmt, fmt, (uint16_t*)data);
-    case TypeDesc::SHORT: return sprintt(type, fmt.int_fmt, fmt, (short*)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (uint16_t*)data)
+                   : format_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (uint16_t*)data);
+    case TypeDesc::SHORT:
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.int_fmt, fmt, (short*)data)
+                   : format_type(type, fmt.int_fmt, fmt, (short*)data);
     case TypeDesc::UINT:
         if (type.vecsemantics == TypeDesc::RATIONAL
             && type.aggregate == TypeDesc::VEC2) {
@@ -428,7 +523,7 @@ tostring(TypeDesc type, const void* data, const tostring_formatting& fmt)
             for (size_t i = 0, e = type.numelements(); i < e; ++i, val += 2) {
                 if (i)
                     out += ", ";
-                out += Strutil::sprintf("%d/%d", val[0], val[1]);
+                out += Strutil::sprintf("%u/%u", val[0], val[1]);
             }
             return out;
         } else if (type == TypeTimeCode) {
@@ -442,7 +537,11 @@ tostring(TypeDesc type, const void* data, const tostring_formatting& fmt)
             return Strutil::sprintf("%02d:%02d:%02d:%02d", hours, minutes,
                                     seconds, frame);
         }
-        return sprintt(type, fmt.int_fmt, fmt, (unsigned int*)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (unsigned int*)data)
+                   : format_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (unsigned int*)data);
     case TypeDesc::INT:
         if (type.elementtype() == TypeRational) {
             std::string out;
@@ -454,23 +553,42 @@ tostring(TypeDesc type, const void* data, const tostring_formatting& fmt)
             }
             return out;
         }
-        return sprintt(type, fmt.int_fmt, fmt, (int*)data);
-    case TypeDesc::ULONGLONG:
-        return sprintt(type, fmt.int_fmt, fmt, (const uint64_t*)data);
-    case TypeDesc::LONGLONG:
-        return sprintt(type, fmt.int_fmt, fmt, (const int64_t*)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.int_fmt, fmt, (int*)data)
+                   : format_type(type, fmt.int_fmt, fmt, (int*)data);
+    case TypeDesc::UINT64:
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (const uint64_t*)data)
+                   : format_type(type, fmt.uint_fmt ? fmt.uint_fmt : "%u", fmt,
+                                 (const uint64_t*)data);
+    case TypeDesc::INT64:
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.int_fmt, fmt, (const int64_t*)data)
+                   : format_type(type, fmt.int_fmt, fmt, (const int64_t*)data);
     case TypeDesc::HALF:
-        return sprintt(type, fmt.float_fmt, fmt, (const half*)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.float_fmt, fmt, (const half*)data)
+                   : format_type(type, fmt.float_fmt, fmt, (const half*)data);
     case TypeDesc::FLOAT:
-        return sprintt(type, fmt.float_fmt, fmt, (const float*)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.float_fmt, fmt, (const float*)data)
+                   : format_type(type, fmt.float_fmt, fmt, (const float*)data);
     case TypeDesc::DOUBLE:
-        return sprintt(type, fmt.float_fmt, fmt, (const double*)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.float_fmt, fmt, (const double*)data)
+                   : format_type(type, fmt.float_fmt, fmt, (const double*)data);
     case TypeDesc::STRING:
         if (!type.is_array()
             && !(fmt.flags & tostring_formatting::quote_single_string))
             return *(const char**)data;
-        return sprintt(type, fmt.string_fmt, fmt, (const char**)data);
-    case TypeDesc::PTR: return sprintt(type, fmt.ptr_fmt, fmt, (void**)data);
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.string_fmt, fmt, (const char**)data)
+                   : format_type(type, fmt.string_fmt, fmt, (const char**)data);
+    case TypeDesc::PTR:
+        return fmt.use_sprintf
+                   ? sprint_type(type, fmt.ptr_fmt, fmt, (void**)data)
+                   : format_type(type, fmt.ptr_fmt, fmt, (void**)data);
     default:
 #ifndef NDEBUG
         return Strutil::sprintf("<unknown data type> (base %d, agg %d vec %d)",
@@ -701,6 +819,41 @@ TypeDesc::operator<(const TypeDesc& x) const noexcept
 
 
 
+TypeDesc::BASETYPE
+TypeDesc::basetype_merge(TypeDesc at, TypeDesc bt)
+{
+    BASETYPE a = (BASETYPE)at.basetype;
+    BASETYPE b = (BASETYPE)bt.basetype;
+
+    // Same type already? done.
+    if (a == b)
+        return a;
+    if (a == UNKNOWN)
+        return b;
+    if (b == UNKNOWN)
+        return a;
+    // Canonicalize so a's size (in bytes) is >= b's size in bytes. This
+    // unclutters remaining cases.
+    if (TypeDesc(a).size() < TypeDesc(b).size())
+        std::swap(a, b);
+    // Double or float trump anything else
+    if (a == DOUBLE || a == FLOAT)
+        return a;
+    if (a == UINT32 && (b == UINT16 || b == UINT8))
+        return a;
+    if (a == INT32 && (b == INT16 || b == UINT16 || b == INT8 || b == UINT8))
+        return a;
+    if ((a == UINT16 || a == HALF) && b == UINT8)
+        return a;
+    if ((a == INT16 || a == HALF) && (b == INT8 || b == UINT8))
+        return a;
+    // Out of common cases. For all remaining edge cases, punt and say that
+    // we prefer float.
+    return FLOAT;
+}
+
+
+
 const TypeDesc TypeDesc::TypeFloat(TypeDesc::FLOAT);
 const TypeDesc TypeDesc::TypeColor(TypeDesc::FLOAT, TypeDesc::VEC3,
                                    TypeDesc::COLOR);
