@@ -2,12 +2,11 @@
 // SPDX-License-Identifier: BSD-3-Clause
 // https://github.com/OpenImageIO/oiio/blob/master/LICENSE.md
 
+#include <OpenImageIO/Imath.h>
 #include <OpenImageIO/dassert.h>
 #include <OpenImageIO/filesystem.h>
 #include <OpenImageIO/imageio.h>
 
-#include <OpenEXR/ImathMatrix.h>
-
 #if OIIO_GNUC_VERSION >= 60000
 #    pragma GCC diagnostic ignored "-Wstrict-overflow"
 #endif
@@ -350,7 +349,7 @@ OpenVDBInput::readMetaData(const openvdb::GridBase& grid,
                            const layerrecord& layer, ImageSpec& spec)
 {
     // If two grids of the same name exist in a VDB, then there will be an
-    // object name & a grid name that get concated to make a unique name
+    // object name & a grid name that get concatenated to make a unique name
     // "density[0].density", "density[1].density" for lookup.
     // Otherwise, just use the grid name; so one can do texture3d("Cd") instead
     // of texture3d("Cd.Cd")
@@ -546,8 +545,8 @@ OpenVDBInput::open(const std::string& filename, ImageSpec& newspec)
 
 
 bool
-OpenVDBInput::read_native_scanline(int subimage, int miplevel, int y, int z,
-                                   void* data)
+OpenVDBInput::read_native_scanline(int /*subimage*/, int /*miplevel*/,
+                                   int /*y*/, int /*z*/, void* /*data*/)
 {
     // scanlines not supported
     return false;
