@@ -18,4 +18,10 @@ command += info_command ("nogps.jpg", safematch=True)
 command += oiiotool (OIIO_TESTSUITE_IMAGEDIR+"/tahoe-gps.jpg --eraseattrib \".*\" -o noattribs.jpg")
 command += info_command ("noattribs.jpg", safematch=True)
 
-
+# Test adding and erasing attribs to multiple subimages
+command += oiiotool ("--create 64x64 3 -dup --siappend " +
+                     "--attrib:allsubimages=1 foo bar -d half -o attrib2.exr")
+command += info_command ("attrib2.exr", safematch=True)
+command += oiiotool ("attrib2.exr " +
+                     "--eraseattrib:allsubimages=1 foo -d half -o attrib0.exr")
+command += info_command ("attrib0.exr", safematch=True)
