@@ -145,7 +145,11 @@ try:
     breakdown_test (oiio.TypeDesc.TypeTimeCode, "TypeTimeCode", verbose=False)
     breakdown_test (oiio.TypeDesc.TypeKeyCode,  "TypeKeyCode",  verbose=False)
     breakdown_test (oiio.TypeDesc.TypeRational, "TypeRational", verbose=False)
+    breakdown_test (oiio.TypeDesc.TypeFloat2,   "TypeFloat2",   verbose=False)
+    breakdown_test (oiio.TypeDesc.TypeVector2,  "TypeVector2",  verbose=False)
     breakdown_test (oiio.TypeDesc.TypeFloat4,   "TypeFloat4",   verbose=False)
+    breakdown_test (oiio.TypeDesc.TypeVector4,  "TypeVector4",  verbose=False)
+    breakdown_test (oiio.TypeDesc.TypeVector2i, "TypeVector2i", verbose=False)
     breakdown_test (oiio.TypeDesc.TypeHalf,     "TypeHalf",     verbose=False)
     print ("")
 
@@ -169,7 +173,11 @@ try:
     breakdown_test (oiio.TypeMatrix44, "TypeMatrix44", verbose=False)
     breakdown_test (oiio.TypeTimeCode, "TypeTimeCode", verbose=False)
     breakdown_test (oiio.TypeKeyCode,  "TypeKeyCode",  verbose=False)
+    breakdown_test (oiio.TypeFloat2,   "TypeFloat2",   verbose=False)
+    breakdown_test (oiio.TypeVector2,  "TypeVector2",  verbose=False)
     breakdown_test (oiio.TypeFloat4,   "TypeFloat4",   verbose=False)
+    breakdown_test (oiio.TypeVector4,  "TypeVector4",  verbose=False)
+    breakdown_test (oiio.TypeVector2i, "TypeVector2i", verbose=False)
     breakdown_test (oiio.TypeHalf,     "TypeHalf",     verbose=False)
     breakdown_test (oiio.TypeRational, "TypeRational", verbose=False)
     breakdown_test (oiio.TypeUInt,     "TypeUInt",     verbose=False)
